@@ -4,7 +4,6 @@ from laboro.error import LaboroError
 from laboro.history import History
 from laboro.workspace import Workspace
 from laboro.context.store import Store
-from laboro.config.manager import Manager as ConfigMgr
 from laboro.module.manager import Manager as ModuleMgr
 from laboro.error.handler import Handler as ErrorHandler
 
@@ -16,8 +15,7 @@ class Context:
 
   Arguments:
     logger: A ``laboro.logger.manager.Manager`` instance.
-
-    main_config_file: Optional, a string specifying the main **Laboro** configuration file path. Defaults to ``/etc/laboro/laboro.yml``.
+    config_mgr: A ``laboro.config.manager.Manager`` instance.
 
   Raises:
     ``laboro.error.LaboroError``: If the main **Laboro** configuration file is not found or invalid.
@@ -25,93 +23,95 @@ class Context:
   Returns:
     ``laboro.context.Context``
   """
-  def __init__(self, logger, main_config_file="/etc/laboro/laboro.yml"):
+  def __init__(self, logger, config_mgr):
     self.delete_workspace_on_exit = True
     self.logger = logger
     self.store = Store()
     self.history = None
     self.modulemgr = ModuleMgr()
-    self.configmgr = ConfigMgr(main_config_file)
-    self.workspacedir = self.configmgr.get_parameter("main",
-                                                     "$.laboro.workspacedir")
-    self.histdir = self.configmgr.get_parameter("main",
-                                                "$.laboro.histdir")
-    self.workflowdir = self.configmgr.get_parameter("main",
-                                                    "$.laboro.workflowdir")
-    self.logdir = self.configmgr.get_parameter("main",
-                                               "$.laboro.log.dir")
-    self.loglevel = self.configmgr.get_parameter("main",
-                                                 "$.laboro.log.level")
+    self.config_mgr = config_mgr
+    self.workspacedir = self.config_mgr.get_parameter("main",
+                                                      "$.laboro.workspacedir")
+    self.histdir = self.config_mgr.get_parameter("main",
+                                                 "$.laboro.histdir")
+    self.workflowdir = self.config_mgr.get_parameter("main",
+                                                     "$.laboro.workflowdir")
+    self.logdir = self.config_mgr.get_parameter("main",
+                                                "$.laboro.log.dir")
+    self.loglevel = self.config_mgr.get_parameter("main",
+                                                  "$.laboro.log.level")
+    self.workflow_name = None
+    self.workflow_session = None
     self.workspace = None
     logging.getLogger().vault.clear()
 
-  def reset(self, workflow_name, session):
+  def reset(self, session, workspace_cfg):
     """Reset the ``laboro.context.Context`` instance with the new workflow configuration and session.
 
     Arguments:
-      workflow_name: A string specifying the workflow name. The ``workflow_name`` will be used to retrieve the workflow configuration file in the``laboro.workflowdir`` specified in the main configuration file.
       session: A unique string defining a workflow session. Usually a string representation of a uuid.uuid4() instance.
+      workspace_cfg: A dict representing the workspace configuration. See ``laboro.workspace.Workspace`` and ``laboro.workflow.Workflow`` for workspace configuration details.
 
     Raises:
       ``laboro.error.LaboroError``: For various reasons linked to the submodules instantiations.
 
     Returns:
-      ``laboro.context.Context``: The ``Context`` instance reseted with the new parameters.
+      ``laboro.context.Context``: The ``Context`` instance reset with the new parameters.
     """
     try:
-      logging.getLogger().log_section("WORKFLOW",
-                                      f"Started {workflow_name} / {session}")
+      self.workflow_session = session
+      self.workflow_name = self.config_mgr.get_parameter("workflow", "$.name")
+      self.workflow_name = self.workflow_name.replace(" ", "_")
+      start_msg = f"Started {self.workflow_name} / {self.workflow_session}"
+      logging.getLogger().log_section("WORKFLOW", start_msg)
       logging.getLogger().vault.clear()
       self.store.clear()
-      self._configure_logger(workflow_name, session)
-      self._set_workflow_config(workflow_name)
-      self.delete_workspace_on_exit = self.configmgr.get_parameter("workflow", "$.workspace.delete_on_exit")
+      self._configure_logger()
+      self.delete_workspace_on_exit = workspace_cfg["delete_on_exit"]
       self.workspace = Workspace(workspacedir=self.workspacedir,
-                                 workflow=workflow_name,
-                                 session=session)
-      history_path = os.path.join(self.histdir, f"{workflow_name}.db")
+                                 workflow=self.workflow_name,
+                                 session=self.workflow_session)
+      history_path = os.path.join(self.histdir, f"{self.workflow_name}.db")
       self.history = History(filename=history_path,
-                             workflow=workflow_name,
-                             session=session,
-                             params=self.configmgr.workflow_config)
+                             workflow=self.workflow_name,
+                             session=self.workflow_session,
+                             params=self.config_mgr.workflow_config)
       self.history.enter()
       self.install_packages()
       return self
     except Exception as err:
-      ErrorHandler().handle_error(workflow_name,
-                                  session,
+      ErrorHandler().handle_error(self.workflow_name,
+                                  self.workflow_session,
                                   err.__class__,
                                   str(err))
 
-  def exit(self, name, session, kind, value):
+  def exit(self, kind, value):
     """Exit the ``Context`` instance.
     When the instance exit, it triggers the ``laboro.workspace.Workspace``, ``laboro.history.History`` instances exit and close the log linked to the ``laboro.workflow.Workflow`` instance associated with the ``Context`` instance. It also register the exit/error code.
 
     Arguments:
-      name: A string specifying the ``Workflow`` name to close.
-      session: A string specifying the ``Workflow`` session to close.
       kind: The kind of event that triggered the ``Context`` instance exit.
       value: The `value` of the event that triggered the ``Context`` instance exit.
     """
     if self.delete_workspace_on_exit:
       self.workspace.delete()
     self.history.exit(kind, value)
-    ErrorHandler().handle_error(name, session, kind, value)
-    self.logger.remove_file_handler(session)
+    ErrorHandler().handle_error(self.workflow_name,
+                                self.workflow_session,
+                                kind,
+                                value)
+    self.logger.remove_file_handler(self.workflow_session)
 
-  def _configure_logger(self, workflow_name, session):
-    self.logger.add_file_handler(self.logdir, workflow_name, session)
+  def _configure_logger(self):
+    self.logger.add_file_handler(self.logdir,
+                                 self.workflow_name,
+                                 self.workflow_session)
     self.logger.set_log_level(self.loglevel)
 
-  def _set_workflow_config(self, workflow_name):
-    config_file_name = os.path.join(self.workflowdir, f"{workflow_name}.yml")
-    logging.info(f"[+] Loading workflow_config: {config_file_name}")
-    self.configmgr.workflow_config = config_file_name
-
   def install_packages(self):
     """Install all packages listed in the workflow configuration file.
     """
-    packages = self.configmgr.get_parameter("workflow", "$.packages")
+    packages = self.config_mgr.get_parameter("workflow", "$.packages")
     for pkg in packages:
       self.modulemgr.install_package(pkg)
 
