@@ -61,7 +61,7 @@ class Module:
     """Load module specification from its YAML data file."""
     base_spec = os.path.join(os.path.dirname(__file__),
                              "schema",
-                             "object.yml")
+                             "instance.yml")
     spec_file = os.path.join(os.path.dirname(self.filepath),
                              "schema",
                              "specification.yml")
