@@ -70,7 +70,7 @@ class Validator:
         self._validate_implied(arg, args, method)
         self._validate_excluded(arg, args, method)
       else:
-        msg = {"type": "UnknownArgError",
+        msg = {"type": "UnknownMethodArgError",
                "message": f"Unknown argument: {arg}"}
         logging.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}")
@@ -108,7 +108,7 @@ class Validator:
         self._validate_implied(arg, args, obj)
         self._validate_excluded(arg, args, obj)
       else:
-        msg = {"type": "UnknownArgError",
+        msg = {"type": "UnknownObjArgError",
                "message": f"Unknown argument: {arg}"}
         logging.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}")
